@@ -5,15 +5,6 @@
 #include <gail/gailbox.h>
 #include <gail/gailbutton.h>
 #include <gail/gailcalendar.h>
-#include <gail/gailcanvas.h>
-#include <gail/gailcanvasgroup.h>
-#include <gail/gailcanvasgroupfactory.h>
-#include <gail/gailcanvasitem.h>
-#include <gail/gailcanvasitemfactory.h>
-#include <gail/gailcanvastext.h>
-#include <gail/gailcanvastextfactory.h>
-#include <gail/gailcanvaswidget.h>
-#include <gail/gailcanvaswidgetfactory.h>
 #include <gail/gailcell.h>
 #include <gail/gailcheckmenuitem.h>
 #include <gail/gailclist.h>
