@@ -19,7 +19,9 @@
 
 #include <string.h>
 #include <gtk/gtk.h>
+#ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
+#endif
 #include "gailwidget.h"
 #include "gailnotebookpage.h"
 #include "gail-private-macros.h"
@@ -772,7 +774,13 @@ gail_widget_grab_focus (AtkComponent   *component)
       gtk_widget_grab_focus (widget);
       toplevel = gtk_widget_get_toplevel (widget);
       if (GTK_WIDGET_TOPLEVEL (toplevel))
-        gtk_window_present_with_time (GTK_WINDOW (toplevel), gdk_x11_get_server_time (widget->window));
+	{
+#ifdef GDK_WINDOWING_X11
+	  gtk_window_present_with_time (GTK_WINDOW (toplevel), gdk_x11_get_server_time (widget->window));
+#else
+	  gtk_window_present (GTK_WINDOW (toplevel));
+#endif
+	}
       return TRUE;
     }
   else
